``python-interface``
====================

|build status|

``interface`` is a library for declaring interfaces and for statically
asserting that classes implement those interfaces. It aims to provide stricter
semantics and better error messages than Python's built-in ``abc`` module.

``interface`` supports Python 2.7 and Python 3.4+.

For more information, see our `documentation`_.

Installation
~~~~~~~~~~~~

.. code-block:: shell

   $ pip install python-interface

.. _`documentation` : http://interface.readthedocs.io

.. |build status| image:: https://github.com/ssanderson/python-interface/workflows/interface-ci/badge.svg
   :target: https://github.com/ssanderson/python-interface/actions
